use 5.00503;
use strict;
use FindBin;
use lib "$FindBin::Bin/../lib";
use Test::Simply tests => 4;
use Stable::Module;

my $notall = '';

$notall = notall {$_} 1,1,1,1;
ok((not $notall), qq{notall {\$_} 1,1,1,1 $^X @{[__FILE__]}});

$notall = notall {$_} 0,0,0,0;
ok($notall, qq{notall {\$_} 0,0,0,0 $^X @{[__FILE__]}});

$notall = notall {$_} 0,0,0,1;
ok($notall, qq{notall {\$_} 0,0,0,1 $^X @{[__FILE__]}});

$notall = notall {$_} 1,1,1,0;
ok($notall, qq{notall {\$_} 1,1,1,0 $^X @{[__FILE__]}});

__END__
